output

package
v3.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 15, 2025 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockFieldFn

type MockFieldFn struct {
	mock.Mock
}

MockFieldFn is an autogenerated mock type for the FieldFn type

func NewMockFieldFn

func NewMockFieldFn(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockFieldFn

NewMockFieldFn creates a new instance of MockFieldFn. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockFieldFn) EXPECT

func (_m *MockFieldFn) EXPECT() *MockFieldFn_Expecter

func (*MockFieldFn) Execute

func (_m *MockFieldFn) Execute(obj any) string

Execute provides a mock function with given fields: obj

type MockFieldFn_Execute_Call

type MockFieldFn_Execute_Call struct {
	*mock.Call
}

MockFieldFn_Execute_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Execute'

func (*MockFieldFn_Execute_Call) Return

func (*MockFieldFn_Execute_Call) Run

func (_c *MockFieldFn_Execute_Call) Run(run func(obj any)) *MockFieldFn_Execute_Call

func (*MockFieldFn_Execute_Call) RunAndReturn

func (_c *MockFieldFn_Execute_Call) RunAndReturn(run func(any) string) *MockFieldFn_Execute_Call

type MockFieldFn_Expecter

type MockFieldFn_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockFieldFn_Expecter) Execute

func (_e *MockFieldFn_Expecter) Execute(obj interface{}) *MockFieldFn_Execute_Call

Execute is a helper method to define mock.On call

  • obj any

Jump to