types

package
v3.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 15, 2025 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockBackend

type MockBackend struct {
	mock.Mock
}

MockBackend is an autogenerated mock type for the Backend type

func NewMockBackend

func NewMockBackend(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockBackend

NewMockBackend creates a new instance of MockBackend. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockBackend) DestroyStep

func (_mock *MockBackend) DestroyStep(ctx context.Context, step *types.Step, taskUUID string) error

DestroyStep provides a mock function for the type MockBackend

func (*MockBackend) DestroyWorkflow

func (_mock *MockBackend) DestroyWorkflow(ctx context.Context, conf *types.Config, taskUUID string) error

DestroyWorkflow provides a mock function for the type MockBackend

func (*MockBackend) EXPECT

func (_m *MockBackend) EXPECT() *MockBackend_Expecter

func (*MockBackend) Flags

func (_mock *MockBackend) Flags() []cli.Flag

Flags provides a mock function for the type MockBackend

func (*MockBackend) IsAvailable

func (_mock *MockBackend) IsAvailable(ctx context.Context) bool

IsAvailable provides a mock function for the type MockBackend

func (*MockBackend) Load

func (_mock *MockBackend) Load(ctx context.Context) (*types.BackendInfo, error)

Load provides a mock function for the type MockBackend

func (*MockBackend) Name

func (_mock *MockBackend) Name() string

Name provides a mock function for the type MockBackend

func (*MockBackend) SetupWorkflow

func (_mock *MockBackend) SetupWorkflow(ctx context.Context, conf *types.Config, taskUUID string) error

SetupWorkflow provides a mock function for the type MockBackend

func (*MockBackend) StartStep

func (_mock *MockBackend) StartStep(ctx context.Context, step *types.Step, taskUUID string) error

StartStep provides a mock function for the type MockBackend

func (*MockBackend) TailStep

func (_mock *MockBackend) TailStep(ctx context.Context, step *types.Step, taskUUID string) (io.ReadCloser, error)

TailStep provides a mock function for the type MockBackend

func (*MockBackend) WaitStep

func (_mock *MockBackend) WaitStep(ctx context.Context, step *types.Step, taskUUID string) (*types.State, error)

WaitStep provides a mock function for the type MockBackend

type MockBackend_DestroyStep_Call

type MockBackend_DestroyStep_Call struct {
	*mock.Call
}

MockBackend_DestroyStep_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'DestroyStep'

func (*MockBackend_DestroyStep_Call) Return

func (*MockBackend_DestroyStep_Call) Run

func (*MockBackend_DestroyStep_Call) RunAndReturn

func (_c *MockBackend_DestroyStep_Call) RunAndReturn(run func(ctx context.Context, step *types.Step, taskUUID string) error) *MockBackend_DestroyStep_Call

type MockBackend_DestroyWorkflow_Call

type MockBackend_DestroyWorkflow_Call struct {
	*mock.Call
}

MockBackend_DestroyWorkflow_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'DestroyWorkflow'

func (*MockBackend_DestroyWorkflow_Call) Return

func (*MockBackend_DestroyWorkflow_Call) Run

func (*MockBackend_DestroyWorkflow_Call) RunAndReturn

type MockBackend_Expecter

type MockBackend_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockBackend_Expecter) DestroyStep

func (_e *MockBackend_Expecter) DestroyStep(ctx interface{}, step interface{}, taskUUID interface{}) *MockBackend_DestroyStep_Call

DestroyStep is a helper method to define mock.On call

  • ctx
  • step
  • taskUUID

func (*MockBackend_Expecter) DestroyWorkflow

func (_e *MockBackend_Expecter) DestroyWorkflow(ctx interface{}, conf interface{}, taskUUID interface{}) *MockBackend_DestroyWorkflow_Call

DestroyWorkflow is a helper method to define mock.On call

  • ctx
  • conf
  • taskUUID

func (*MockBackend_Expecter) Flags

Flags is a helper method to define mock.On call

func (*MockBackend_Expecter) IsAvailable

func (_e *MockBackend_Expecter) IsAvailable(ctx interface{}) *MockBackend_IsAvailable_Call

IsAvailable is a helper method to define mock.On call

  • ctx

func (*MockBackend_Expecter) Load

func (_e *MockBackend_Expecter) Load(ctx interface{}) *MockBackend_Load_Call

Load is a helper method to define mock.On call

  • ctx

func (*MockBackend_Expecter) Name

Name is a helper method to define mock.On call

func (*MockBackend_Expecter) SetupWorkflow

func (_e *MockBackend_Expecter) SetupWorkflow(ctx interface{}, conf interface{}, taskUUID interface{}) *MockBackend_SetupWorkflow_Call

SetupWorkflow is a helper method to define mock.On call

  • ctx
  • conf
  • taskUUID

func (*MockBackend_Expecter) StartStep

func (_e *MockBackend_Expecter) StartStep(ctx interface{}, step interface{}, taskUUID interface{}) *MockBackend_StartStep_Call

StartStep is a helper method to define mock.On call

  • ctx
  • step
  • taskUUID

func (*MockBackend_Expecter) TailStep

func (_e *MockBackend_Expecter) TailStep(ctx interface{}, step interface{}, taskUUID interface{}) *MockBackend_TailStep_Call

TailStep is a helper method to define mock.On call

  • ctx
  • step
  • taskUUID

func (*MockBackend_Expecter) WaitStep

func (_e *MockBackend_Expecter) WaitStep(ctx interface{}, step interface{}, taskUUID interface{}) *MockBackend_WaitStep_Call

WaitStep is a helper method to define mock.On call

  • ctx
  • step
  • taskUUID

type MockBackend_Flags_Call

type MockBackend_Flags_Call struct {
	*mock.Call
}

MockBackend_Flags_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Flags'

func (*MockBackend_Flags_Call) Return

func (*MockBackend_Flags_Call) Run

func (_c *MockBackend_Flags_Call) Run(run func()) *MockBackend_Flags_Call

func (*MockBackend_Flags_Call) RunAndReturn

func (_c *MockBackend_Flags_Call) RunAndReturn(run func() []cli.Flag) *MockBackend_Flags_Call

type MockBackend_IsAvailable_Call

type MockBackend_IsAvailable_Call struct {
	*mock.Call
}

MockBackend_IsAvailable_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'IsAvailable'

func (*MockBackend_IsAvailable_Call) Return

func (*MockBackend_IsAvailable_Call) Run

func (*MockBackend_IsAvailable_Call) RunAndReturn

type MockBackend_Load_Call

type MockBackend_Load_Call struct {
	*mock.Call
}

MockBackend_Load_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Load'

func (*MockBackend_Load_Call) Return

func (_c *MockBackend_Load_Call) Return(backendInfo *types.BackendInfo, err error) *MockBackend_Load_Call

func (*MockBackend_Load_Call) Run

func (*MockBackend_Load_Call) RunAndReturn

func (_c *MockBackend_Load_Call) RunAndReturn(run func(ctx context.Context) (*types.BackendInfo, error)) *MockBackend_Load_Call

type MockBackend_Name_Call

type MockBackend_Name_Call struct {
	*mock.Call
}

MockBackend_Name_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Name'

func (*MockBackend_Name_Call) Return

func (*MockBackend_Name_Call) Run

func (_c *MockBackend_Name_Call) Run(run func()) *MockBackend_Name_Call

func (*MockBackend_Name_Call) RunAndReturn

func (_c *MockBackend_Name_Call) RunAndReturn(run func() string) *MockBackend_Name_Call

type MockBackend_SetupWorkflow_Call

type MockBackend_SetupWorkflow_Call struct {
	*mock.Call
}

MockBackend_SetupWorkflow_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'SetupWorkflow'

func (*MockBackend_SetupWorkflow_Call) Return

func (*MockBackend_SetupWorkflow_Call) Run

func (*MockBackend_SetupWorkflow_Call) RunAndReturn

func (_c *MockBackend_SetupWorkflow_Call) RunAndReturn(run func(ctx context.Context, conf *types.Config, taskUUID string) error) *MockBackend_SetupWorkflow_Call

type MockBackend_StartStep_Call

type MockBackend_StartStep_Call struct {
	*mock.Call
}

MockBackend_StartStep_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'StartStep'

func (*MockBackend_StartStep_Call) Return

func (*MockBackend_StartStep_Call) Run

func (_c *MockBackend_StartStep_Call) Run(run func(ctx context.Context, step *types.Step, taskUUID string)) *MockBackend_StartStep_Call

func (*MockBackend_StartStep_Call) RunAndReturn

func (_c *MockBackend_StartStep_Call) RunAndReturn(run func(ctx context.Context, step *types.Step, taskUUID string) error) *MockBackend_StartStep_Call

type MockBackend_TailStep_Call

type MockBackend_TailStep_Call struct {
	*mock.Call
}

MockBackend_TailStep_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'TailStep'

func (*MockBackend_TailStep_Call) Return

func (*MockBackend_TailStep_Call) Run

func (_c *MockBackend_TailStep_Call) Run(run func(ctx context.Context, step *types.Step, taskUUID string)) *MockBackend_TailStep_Call

func (*MockBackend_TailStep_Call) RunAndReturn

func (_c *MockBackend_TailStep_Call) RunAndReturn(run func(ctx context.Context, step *types.Step, taskUUID string) (io.ReadCloser, error)) *MockBackend_TailStep_Call

type MockBackend_WaitStep_Call

type MockBackend_WaitStep_Call struct {
	*mock.Call
}

MockBackend_WaitStep_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'WaitStep'

func (*MockBackend_WaitStep_Call) Return

func (*MockBackend_WaitStep_Call) Run

func (_c *MockBackend_WaitStep_Call) Run(run func(ctx context.Context, step *types.Step, taskUUID string)) *MockBackend_WaitStep_Call

func (*MockBackend_WaitStep_Call) RunAndReturn

func (_c *MockBackend_WaitStep_Call) RunAndReturn(run func(ctx context.Context, step *types.Step, taskUUID string) (*types.State, error)) *MockBackend_WaitStep_Call

Jump to