Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BoolTrue ¶
type BoolTrue struct {
// contains filtered or unexported fields
}
BoolTrue is a custom Yaml boolean type that defaults to true.
type EnvironmentMap ¶
func (*EnvironmentMap) UnmarshalYAML ¶
func (s *EnvironmentMap) UnmarshalYAML(unmarshal func(any) error) error
UnmarshalYAML implements the Unmarshaler interface.
type MemStringOrInt ¶
type MemStringOrInt int64
MemStringOrInt represents a string or an integer the String supports notations like 10m for then Megabyte of memory.
func (*MemStringOrInt) UnmarshalYAML ¶
func (s *MemStringOrInt) UnmarshalYAML(unmarshal func(any) error) error
UnmarshalYAML implements the Unmarshaler interface.
type StringOrInt ¶
type StringOrInt int64
StringOrInt represents a string or an integer.
func (*StringOrInt) UnmarshalYAML ¶
func (s *StringOrInt) UnmarshalYAML(unmarshal func(any) error) error
UnmarshalYAML implements the Unmarshaler interface.
type StringOrSlice ¶
type StringOrSlice []string
StringOrSlice represents a string or an array of strings. We need to override the yaml decoder to accept both options.
func (*StringOrSlice) UnmarshalYAML ¶
func (s *StringOrSlice) UnmarshalYAML(unmarshal func(any) error) error
UnmarshalYAML implements the Unmarshaler interface.
Click to show internal directories.
Click to hide internal directories.