Documentation
¶
Index ¶
- type MockSecretStore
- func (_m *MockSecretStore) EXPECT() *MockSecretStore_Expecter
- func (_mock *MockSecretStore) GlobalSecretFind(s string) (*model.Secret, error)
- func (_mock *MockSecretStore) GlobalSecretList(listOptions *model.ListOptions) ([]*model.Secret, error)
- func (_mock *MockSecretStore) OrgSecretFind(n int64, s string) (*model.Secret, error)
- func (_mock *MockSecretStore) OrgSecretList(n int64, listOptions *model.ListOptions) ([]*model.Secret, error)
- func (_mock *MockSecretStore) SecretCreate(secret *model.Secret) error
- func (_mock *MockSecretStore) SecretDelete(secret *model.Secret) error
- func (_mock *MockSecretStore) SecretFind(repo *model.Repo, s string) (*model.Secret, error)
- func (_mock *MockSecretStore) SecretList(repo *model.Repo, b bool, listOptions *model.ListOptions) ([]*model.Secret, error)
- func (_mock *MockSecretStore) SecretListAll() ([]*model.Secret, error)
- func (_mock *MockSecretStore) SecretUpdate(secret *model.Secret) error
- type MockSecretStore_Expecter
- func (_e *MockSecretStore_Expecter) GlobalSecretFind(s interface{}) *MockSecretStore_GlobalSecretFind_Call
- func (_e *MockSecretStore_Expecter) GlobalSecretList(listOptions interface{}) *MockSecretStore_GlobalSecretList_Call
- func (_e *MockSecretStore_Expecter) OrgSecretFind(n interface{}, s interface{}) *MockSecretStore_OrgSecretFind_Call
- func (_e *MockSecretStore_Expecter) OrgSecretList(n interface{}, listOptions interface{}) *MockSecretStore_OrgSecretList_Call
- func (_e *MockSecretStore_Expecter) SecretCreate(secret interface{}) *MockSecretStore_SecretCreate_Call
- func (_e *MockSecretStore_Expecter) SecretDelete(secret interface{}) *MockSecretStore_SecretDelete_Call
- func (_e *MockSecretStore_Expecter) SecretFind(repo interface{}, s interface{}) *MockSecretStore_SecretFind_Call
- func (_e *MockSecretStore_Expecter) SecretList(repo interface{}, b interface{}, listOptions interface{}) *MockSecretStore_SecretList_Call
- func (_e *MockSecretStore_Expecter) SecretListAll() *MockSecretStore_SecretListAll_Call
- func (_e *MockSecretStore_Expecter) SecretUpdate(secret interface{}) *MockSecretStore_SecretUpdate_Call
- type MockSecretStore_GlobalSecretFind_Call
- func (_c *MockSecretStore_GlobalSecretFind_Call) Return(secret *model.Secret, err error) *MockSecretStore_GlobalSecretFind_Call
- func (_c *MockSecretStore_GlobalSecretFind_Call) Run(run func(s string)) *MockSecretStore_GlobalSecretFind_Call
- func (_c *MockSecretStore_GlobalSecretFind_Call) RunAndReturn(run func(s string) (*model.Secret, error)) *MockSecretStore_GlobalSecretFind_Call
- type MockSecretStore_GlobalSecretList_Call
- func (_c *MockSecretStore_GlobalSecretList_Call) Return(secrets []*model.Secret, err error) *MockSecretStore_GlobalSecretList_Call
- func (_c *MockSecretStore_GlobalSecretList_Call) Run(run func(listOptions *model.ListOptions)) *MockSecretStore_GlobalSecretList_Call
- func (_c *MockSecretStore_GlobalSecretList_Call) RunAndReturn(run func(listOptions *model.ListOptions) ([]*model.Secret, error)) *MockSecretStore_GlobalSecretList_Call
- type MockSecretStore_OrgSecretFind_Call
- func (_c *MockSecretStore_OrgSecretFind_Call) Return(secret *model.Secret, err error) *MockSecretStore_OrgSecretFind_Call
- func (_c *MockSecretStore_OrgSecretFind_Call) Run(run func(n int64, s string)) *MockSecretStore_OrgSecretFind_Call
- func (_c *MockSecretStore_OrgSecretFind_Call) RunAndReturn(run func(n int64, s string) (*model.Secret, error)) *MockSecretStore_OrgSecretFind_Call
- type MockSecretStore_OrgSecretList_Call
- func (_c *MockSecretStore_OrgSecretList_Call) Return(secrets []*model.Secret, err error) *MockSecretStore_OrgSecretList_Call
- func (_c *MockSecretStore_OrgSecretList_Call) Run(run func(n int64, listOptions *model.ListOptions)) *MockSecretStore_OrgSecretList_Call
- func (_c *MockSecretStore_OrgSecretList_Call) RunAndReturn(run func(n int64, listOptions *model.ListOptions) ([]*model.Secret, error)) *MockSecretStore_OrgSecretList_Call
- type MockSecretStore_SecretCreate_Call
- func (_c *MockSecretStore_SecretCreate_Call) Return(err error) *MockSecretStore_SecretCreate_Call
- func (_c *MockSecretStore_SecretCreate_Call) Run(run func(secret *model.Secret)) *MockSecretStore_SecretCreate_Call
- func (_c *MockSecretStore_SecretCreate_Call) RunAndReturn(run func(secret *model.Secret) error) *MockSecretStore_SecretCreate_Call
- type MockSecretStore_SecretDelete_Call
- func (_c *MockSecretStore_SecretDelete_Call) Return(err error) *MockSecretStore_SecretDelete_Call
- func (_c *MockSecretStore_SecretDelete_Call) Run(run func(secret *model.Secret)) *MockSecretStore_SecretDelete_Call
- func (_c *MockSecretStore_SecretDelete_Call) RunAndReturn(run func(secret *model.Secret) error) *MockSecretStore_SecretDelete_Call
- type MockSecretStore_SecretFind_Call
- func (_c *MockSecretStore_SecretFind_Call) Return(secret *model.Secret, err error) *MockSecretStore_SecretFind_Call
- func (_c *MockSecretStore_SecretFind_Call) Run(run func(repo *model.Repo, s string)) *MockSecretStore_SecretFind_Call
- func (_c *MockSecretStore_SecretFind_Call) RunAndReturn(run func(repo *model.Repo, s string) (*model.Secret, error)) *MockSecretStore_SecretFind_Call
- type MockSecretStore_SecretListAll_Call
- func (_c *MockSecretStore_SecretListAll_Call) Return(secrets []*model.Secret, err error) *MockSecretStore_SecretListAll_Call
- func (_c *MockSecretStore_SecretListAll_Call) Run(run func()) *MockSecretStore_SecretListAll_Call
- func (_c *MockSecretStore_SecretListAll_Call) RunAndReturn(run func() ([]*model.Secret, error)) *MockSecretStore_SecretListAll_Call
- type MockSecretStore_SecretList_Call
- func (_c *MockSecretStore_SecretList_Call) Return(secrets []*model.Secret, err error) *MockSecretStore_SecretList_Call
- func (_c *MockSecretStore_SecretList_Call) Run(run func(repo *model.Repo, b bool, listOptions *model.ListOptions)) *MockSecretStore_SecretList_Call
- func (_c *MockSecretStore_SecretList_Call) RunAndReturn(...) *MockSecretStore_SecretList_Call
- type MockSecretStore_SecretUpdate_Call
- func (_c *MockSecretStore_SecretUpdate_Call) Return(err error) *MockSecretStore_SecretUpdate_Call
- func (_c *MockSecretStore_SecretUpdate_Call) Run(run func(secret *model.Secret)) *MockSecretStore_SecretUpdate_Call
- func (_c *MockSecretStore_SecretUpdate_Call) RunAndReturn(run func(secret *model.Secret) error) *MockSecretStore_SecretUpdate_Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockSecretStore ¶
MockSecretStore is an autogenerated mock type for the SecretStore type
func NewMockSecretStore ¶
func NewMockSecretStore(t interface {
mock.TestingT
Cleanup(func())
}) *MockSecretStore
NewMockSecretStore creates a new instance of MockSecretStore. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MockSecretStore) EXPECT ¶
func (_m *MockSecretStore) EXPECT() *MockSecretStore_Expecter
func (*MockSecretStore) GlobalSecretFind ¶
func (_mock *MockSecretStore) GlobalSecretFind(s string) (*model.Secret, error)
GlobalSecretFind provides a mock function for the type MockSecretStore
func (*MockSecretStore) GlobalSecretList ¶
func (_mock *MockSecretStore) GlobalSecretList(listOptions *model.ListOptions) ([]*model.Secret, error)
GlobalSecretList provides a mock function for the type MockSecretStore
func (*MockSecretStore) OrgSecretFind ¶
OrgSecretFind provides a mock function for the type MockSecretStore
func (*MockSecretStore) OrgSecretList ¶
func (_mock *MockSecretStore) OrgSecretList(n int64, listOptions *model.ListOptions) ([]*model.Secret, error)
OrgSecretList provides a mock function for the type MockSecretStore
func (*MockSecretStore) SecretCreate ¶
func (_mock *MockSecretStore) SecretCreate(secret *model.Secret) error
SecretCreate provides a mock function for the type MockSecretStore
func (*MockSecretStore) SecretDelete ¶
func (_mock *MockSecretStore) SecretDelete(secret *model.Secret) error
SecretDelete provides a mock function for the type MockSecretStore
func (*MockSecretStore) SecretFind ¶
SecretFind provides a mock function for the type MockSecretStore
func (*MockSecretStore) SecretList ¶
func (_mock *MockSecretStore) SecretList(repo *model.Repo, b bool, listOptions *model.ListOptions) ([]*model.Secret, error)
SecretList provides a mock function for the type MockSecretStore
func (*MockSecretStore) SecretListAll ¶
func (_mock *MockSecretStore) SecretListAll() ([]*model.Secret, error)
SecretListAll provides a mock function for the type MockSecretStore
func (*MockSecretStore) SecretUpdate ¶
func (_mock *MockSecretStore) SecretUpdate(secret *model.Secret) error
SecretUpdate provides a mock function for the type MockSecretStore
type MockSecretStore_Expecter ¶
type MockSecretStore_Expecter struct {
// contains filtered or unexported fields
}
func (*MockSecretStore_Expecter) GlobalSecretFind ¶
func (_e *MockSecretStore_Expecter) GlobalSecretFind(s interface{}) *MockSecretStore_GlobalSecretFind_Call
GlobalSecretFind is a helper method to define mock.On call
- s
func (*MockSecretStore_Expecter) GlobalSecretList ¶
func (_e *MockSecretStore_Expecter) GlobalSecretList(listOptions interface{}) *MockSecretStore_GlobalSecretList_Call
GlobalSecretList is a helper method to define mock.On call
- listOptions
func (*MockSecretStore_Expecter) OrgSecretFind ¶
func (_e *MockSecretStore_Expecter) OrgSecretFind(n interface{}, s interface{}) *MockSecretStore_OrgSecretFind_Call
OrgSecretFind is a helper method to define mock.On call
- n
- s
func (*MockSecretStore_Expecter) OrgSecretList ¶
func (_e *MockSecretStore_Expecter) OrgSecretList(n interface{}, listOptions interface{}) *MockSecretStore_OrgSecretList_Call
OrgSecretList is a helper method to define mock.On call
- n
- listOptions
func (*MockSecretStore_Expecter) SecretCreate ¶
func (_e *MockSecretStore_Expecter) SecretCreate(secret interface{}) *MockSecretStore_SecretCreate_Call
SecretCreate is a helper method to define mock.On call
- secret
func (*MockSecretStore_Expecter) SecretDelete ¶
func (_e *MockSecretStore_Expecter) SecretDelete(secret interface{}) *MockSecretStore_SecretDelete_Call
SecretDelete is a helper method to define mock.On call
- secret
func (*MockSecretStore_Expecter) SecretFind ¶
func (_e *MockSecretStore_Expecter) SecretFind(repo interface{}, s interface{}) *MockSecretStore_SecretFind_Call
SecretFind is a helper method to define mock.On call
- repo
- s
func (*MockSecretStore_Expecter) SecretList ¶
func (_e *MockSecretStore_Expecter) SecretList(repo interface{}, b interface{}, listOptions interface{}) *MockSecretStore_SecretList_Call
SecretList is a helper method to define mock.On call
- repo
- b
- listOptions
func (*MockSecretStore_Expecter) SecretListAll ¶
func (_e *MockSecretStore_Expecter) SecretListAll() *MockSecretStore_SecretListAll_Call
SecretListAll is a helper method to define mock.On call
func (*MockSecretStore_Expecter) SecretUpdate ¶
func (_e *MockSecretStore_Expecter) SecretUpdate(secret interface{}) *MockSecretStore_SecretUpdate_Call
SecretUpdate is a helper method to define mock.On call
- secret
type MockSecretStore_GlobalSecretFind_Call ¶
MockSecretStore_GlobalSecretFind_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GlobalSecretFind'
func (*MockSecretStore_GlobalSecretFind_Call) Return ¶
func (_c *MockSecretStore_GlobalSecretFind_Call) Return(secret *model.Secret, err error) *MockSecretStore_GlobalSecretFind_Call
func (*MockSecretStore_GlobalSecretFind_Call) Run ¶
func (_c *MockSecretStore_GlobalSecretFind_Call) Run(run func(s string)) *MockSecretStore_GlobalSecretFind_Call
func (*MockSecretStore_GlobalSecretFind_Call) RunAndReturn ¶
func (_c *MockSecretStore_GlobalSecretFind_Call) RunAndReturn(run func(s string) (*model.Secret, error)) *MockSecretStore_GlobalSecretFind_Call
type MockSecretStore_GlobalSecretList_Call ¶
MockSecretStore_GlobalSecretList_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GlobalSecretList'
func (*MockSecretStore_GlobalSecretList_Call) Return ¶
func (_c *MockSecretStore_GlobalSecretList_Call) Return(secrets []*model.Secret, err error) *MockSecretStore_GlobalSecretList_Call
func (*MockSecretStore_GlobalSecretList_Call) Run ¶
func (_c *MockSecretStore_GlobalSecretList_Call) Run(run func(listOptions *model.ListOptions)) *MockSecretStore_GlobalSecretList_Call
func (*MockSecretStore_GlobalSecretList_Call) RunAndReturn ¶
func (_c *MockSecretStore_GlobalSecretList_Call) RunAndReturn(run func(listOptions *model.ListOptions) ([]*model.Secret, error)) *MockSecretStore_GlobalSecretList_Call
type MockSecretStore_OrgSecretFind_Call ¶
MockSecretStore_OrgSecretFind_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OrgSecretFind'
func (*MockSecretStore_OrgSecretFind_Call) Return ¶
func (_c *MockSecretStore_OrgSecretFind_Call) Return(secret *model.Secret, err error) *MockSecretStore_OrgSecretFind_Call
func (*MockSecretStore_OrgSecretFind_Call) Run ¶
func (_c *MockSecretStore_OrgSecretFind_Call) Run(run func(n int64, s string)) *MockSecretStore_OrgSecretFind_Call
func (*MockSecretStore_OrgSecretFind_Call) RunAndReturn ¶
func (_c *MockSecretStore_OrgSecretFind_Call) RunAndReturn(run func(n int64, s string) (*model.Secret, error)) *MockSecretStore_OrgSecretFind_Call
type MockSecretStore_OrgSecretList_Call ¶
MockSecretStore_OrgSecretList_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'OrgSecretList'
func (*MockSecretStore_OrgSecretList_Call) Return ¶
func (_c *MockSecretStore_OrgSecretList_Call) Return(secrets []*model.Secret, err error) *MockSecretStore_OrgSecretList_Call
func (*MockSecretStore_OrgSecretList_Call) Run ¶
func (_c *MockSecretStore_OrgSecretList_Call) Run(run func(n int64, listOptions *model.ListOptions)) *MockSecretStore_OrgSecretList_Call
func (*MockSecretStore_OrgSecretList_Call) RunAndReturn ¶
func (_c *MockSecretStore_OrgSecretList_Call) RunAndReturn(run func(n int64, listOptions *model.ListOptions) ([]*model.Secret, error)) *MockSecretStore_OrgSecretList_Call
type MockSecretStore_SecretCreate_Call ¶
MockSecretStore_SecretCreate_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'SecretCreate'
func (*MockSecretStore_SecretCreate_Call) Return ¶
func (_c *MockSecretStore_SecretCreate_Call) Return(err error) *MockSecretStore_SecretCreate_Call
func (*MockSecretStore_SecretCreate_Call) Run ¶
func (_c *MockSecretStore_SecretCreate_Call) Run(run func(secret *model.Secret)) *MockSecretStore_SecretCreate_Call
func (*MockSecretStore_SecretCreate_Call) RunAndReturn ¶
func (_c *MockSecretStore_SecretCreate_Call) RunAndReturn(run func(secret *model.Secret) error) *MockSecretStore_SecretCreate_Call
type MockSecretStore_SecretDelete_Call ¶
MockSecretStore_SecretDelete_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'SecretDelete'
func (*MockSecretStore_SecretDelete_Call) Return ¶
func (_c *MockSecretStore_SecretDelete_Call) Return(err error) *MockSecretStore_SecretDelete_Call
func (*MockSecretStore_SecretDelete_Call) Run ¶
func (_c *MockSecretStore_SecretDelete_Call) Run(run func(secret *model.Secret)) *MockSecretStore_SecretDelete_Call
func (*MockSecretStore_SecretDelete_Call) RunAndReturn ¶
func (_c *MockSecretStore_SecretDelete_Call) RunAndReturn(run func(secret *model.Secret) error) *MockSecretStore_SecretDelete_Call
type MockSecretStore_SecretFind_Call ¶
MockSecretStore_SecretFind_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'SecretFind'
func (*MockSecretStore_SecretFind_Call) Return ¶
func (_c *MockSecretStore_SecretFind_Call) Return(secret *model.Secret, err error) *MockSecretStore_SecretFind_Call
func (*MockSecretStore_SecretFind_Call) Run ¶
func (_c *MockSecretStore_SecretFind_Call) Run(run func(repo *model.Repo, s string)) *MockSecretStore_SecretFind_Call
func (*MockSecretStore_SecretFind_Call) RunAndReturn ¶
func (_c *MockSecretStore_SecretFind_Call) RunAndReturn(run func(repo *model.Repo, s string) (*model.Secret, error)) *MockSecretStore_SecretFind_Call
type MockSecretStore_SecretListAll_Call ¶
MockSecretStore_SecretListAll_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'SecretListAll'
func (*MockSecretStore_SecretListAll_Call) Return ¶
func (_c *MockSecretStore_SecretListAll_Call) Return(secrets []*model.Secret, err error) *MockSecretStore_SecretListAll_Call
func (*MockSecretStore_SecretListAll_Call) Run ¶
func (_c *MockSecretStore_SecretListAll_Call) Run(run func()) *MockSecretStore_SecretListAll_Call
func (*MockSecretStore_SecretListAll_Call) RunAndReturn ¶
func (_c *MockSecretStore_SecretListAll_Call) RunAndReturn(run func() ([]*model.Secret, error)) *MockSecretStore_SecretListAll_Call
type MockSecretStore_SecretList_Call ¶
MockSecretStore_SecretList_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'SecretList'
func (*MockSecretStore_SecretList_Call) Return ¶
func (_c *MockSecretStore_SecretList_Call) Return(secrets []*model.Secret, err error) *MockSecretStore_SecretList_Call
func (*MockSecretStore_SecretList_Call) Run ¶
func (_c *MockSecretStore_SecretList_Call) Run(run func(repo *model.Repo, b bool, listOptions *model.ListOptions)) *MockSecretStore_SecretList_Call
func (*MockSecretStore_SecretList_Call) RunAndReturn ¶
func (_c *MockSecretStore_SecretList_Call) RunAndReturn(run func(repo *model.Repo, b bool, listOptions *model.ListOptions) ([]*model.Secret, error)) *MockSecretStore_SecretList_Call
type MockSecretStore_SecretUpdate_Call ¶
MockSecretStore_SecretUpdate_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'SecretUpdate'
func (*MockSecretStore_SecretUpdate_Call) Return ¶
func (_c *MockSecretStore_SecretUpdate_Call) Return(err error) *MockSecretStore_SecretUpdate_Call
func (*MockSecretStore_SecretUpdate_Call) Run ¶
func (_c *MockSecretStore_SecretUpdate_Call) Run(run func(secret *model.Secret)) *MockSecretStore_SecretUpdate_Call
func (*MockSecretStore_SecretUpdate_Call) RunAndReturn ¶
func (_c *MockSecretStore_SecretUpdate_Call) RunAndReturn(run func(secret *model.Secret) error) *MockSecretStore_SecretUpdate_Call