types

package
v3.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 15, 2025 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockEncryptionBuilder

type MockEncryptionBuilder struct {
	mock.Mock
}

MockEncryptionBuilder is an autogenerated mock type for the EncryptionBuilder type

func NewMockEncryptionBuilder

func NewMockEncryptionBuilder(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockEncryptionBuilder

NewMockEncryptionBuilder creates a new instance of MockEncryptionBuilder. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockEncryptionBuilder) Build

func (_mock *MockEncryptionBuilder) Build() error

Build provides a mock function for the type MockEncryptionBuilder

func (*MockEncryptionBuilder) EXPECT

func (*MockEncryptionBuilder) WithClient

WithClient provides a mock function for the type MockEncryptionBuilder

type MockEncryptionBuilder_Build_Call

type MockEncryptionBuilder_Build_Call struct {
	*mock.Call
}

MockEncryptionBuilder_Build_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Build'

func (*MockEncryptionBuilder_Build_Call) Return

func (*MockEncryptionBuilder_Build_Call) Run

func (*MockEncryptionBuilder_Build_Call) RunAndReturn

type MockEncryptionBuilder_Expecter

type MockEncryptionBuilder_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockEncryptionBuilder_Expecter) Build

Build is a helper method to define mock.On call

func (*MockEncryptionBuilder_Expecter) WithClient

func (_e *MockEncryptionBuilder_Expecter) WithClient(client interface{}) *MockEncryptionBuilder_WithClient_Call

WithClient is a helper method to define mock.On call

  • client

type MockEncryptionBuilder_WithClient_Call

type MockEncryptionBuilder_WithClient_Call struct {
	*mock.Call
}

MockEncryptionBuilder_WithClient_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'WithClient'

func (*MockEncryptionBuilder_WithClient_Call) Return

func (*MockEncryptionBuilder_WithClient_Call) Run

func (*MockEncryptionBuilder_WithClient_Call) RunAndReturn

type MockEncryptionClient

type MockEncryptionClient struct {
	mock.Mock
}

MockEncryptionClient is an autogenerated mock type for the EncryptionClient type

func NewMockEncryptionClient

func NewMockEncryptionClient(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockEncryptionClient

NewMockEncryptionClient creates a new instance of MockEncryptionClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockEncryptionClient) EXPECT

func (*MockEncryptionClient) EnableEncryption

func (_mock *MockEncryptionClient) EnableEncryption() error

EnableEncryption provides a mock function for the type MockEncryptionClient

func (*MockEncryptionClient) MigrateEncryption

func (_mock *MockEncryptionClient) MigrateEncryption(newEncryption types.EncryptionService) error

MigrateEncryption provides a mock function for the type MockEncryptionClient

func (*MockEncryptionClient) SetEncryptionService

func (_mock *MockEncryptionClient) SetEncryptionService(encryption types.EncryptionService) error

SetEncryptionService provides a mock function for the type MockEncryptionClient

type MockEncryptionClient_EnableEncryption_Call

type MockEncryptionClient_EnableEncryption_Call struct {
	*mock.Call
}

MockEncryptionClient_EnableEncryption_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'EnableEncryption'

func (*MockEncryptionClient_EnableEncryption_Call) Return

func (*MockEncryptionClient_EnableEncryption_Call) Run

func (*MockEncryptionClient_EnableEncryption_Call) RunAndReturn

type MockEncryptionClient_Expecter

type MockEncryptionClient_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockEncryptionClient_Expecter) EnableEncryption

EnableEncryption is a helper method to define mock.On call

func (*MockEncryptionClient_Expecter) MigrateEncryption

func (_e *MockEncryptionClient_Expecter) MigrateEncryption(newEncryption interface{}) *MockEncryptionClient_MigrateEncryption_Call

MigrateEncryption is a helper method to define mock.On call

  • newEncryption

func (*MockEncryptionClient_Expecter) SetEncryptionService

func (_e *MockEncryptionClient_Expecter) SetEncryptionService(encryption interface{}) *MockEncryptionClient_SetEncryptionService_Call

SetEncryptionService is a helper method to define mock.On call

  • encryption

type MockEncryptionClient_MigrateEncryption_Call

type MockEncryptionClient_MigrateEncryption_Call struct {
	*mock.Call
}

MockEncryptionClient_MigrateEncryption_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'MigrateEncryption'

func (*MockEncryptionClient_MigrateEncryption_Call) Return

func (*MockEncryptionClient_MigrateEncryption_Call) Run

func (*MockEncryptionClient_MigrateEncryption_Call) RunAndReturn

type MockEncryptionClient_SetEncryptionService_Call

type MockEncryptionClient_SetEncryptionService_Call struct {
	*mock.Call
}

MockEncryptionClient_SetEncryptionService_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'SetEncryptionService'

func (*MockEncryptionClient_SetEncryptionService_Call) Return

func (*MockEncryptionClient_SetEncryptionService_Call) Run

func (*MockEncryptionClient_SetEncryptionService_Call) RunAndReturn

type MockEncryptionService

type MockEncryptionService struct {
	mock.Mock
}

MockEncryptionService is an autogenerated mock type for the EncryptionService type

func NewMockEncryptionService

func NewMockEncryptionService(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockEncryptionService

NewMockEncryptionService creates a new instance of MockEncryptionService. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockEncryptionService) Decrypt

func (_mock *MockEncryptionService) Decrypt(ciphertext string, associatedData string) (string, error)

Decrypt provides a mock function for the type MockEncryptionService

func (*MockEncryptionService) Disable

func (_mock *MockEncryptionService) Disable() error

Disable provides a mock function for the type MockEncryptionService

func (*MockEncryptionService) EXPECT

func (*MockEncryptionService) Encrypt

func (_mock *MockEncryptionService) Encrypt(plaintext string, associatedData string) (string, error)

Encrypt provides a mock function for the type MockEncryptionService

type MockEncryptionServiceBuilder

type MockEncryptionServiceBuilder struct {
	mock.Mock
}

MockEncryptionServiceBuilder is an autogenerated mock type for the EncryptionServiceBuilder type

func NewMockEncryptionServiceBuilder

func NewMockEncryptionServiceBuilder(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockEncryptionServiceBuilder

NewMockEncryptionServiceBuilder creates a new instance of MockEncryptionServiceBuilder. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockEncryptionServiceBuilder) Build

Build provides a mock function for the type MockEncryptionServiceBuilder

func (*MockEncryptionServiceBuilder) EXPECT

func (*MockEncryptionServiceBuilder) WithClients

WithClients provides a mock function for the type MockEncryptionServiceBuilder

type MockEncryptionServiceBuilder_Build_Call

type MockEncryptionServiceBuilder_Build_Call struct {
	*mock.Call
}

MockEncryptionServiceBuilder_Build_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Build'

func (*MockEncryptionServiceBuilder_Build_Call) Return

func (*MockEncryptionServiceBuilder_Build_Call) Run

func (*MockEncryptionServiceBuilder_Build_Call) RunAndReturn

type MockEncryptionServiceBuilder_Expecter

type MockEncryptionServiceBuilder_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockEncryptionServiceBuilder_Expecter) Build

Build is a helper method to define mock.On call

func (*MockEncryptionServiceBuilder_Expecter) WithClients

WithClients is a helper method to define mock.On call

  • clients

type MockEncryptionServiceBuilder_WithClients_Call

type MockEncryptionServiceBuilder_WithClients_Call struct {
	*mock.Call
}

MockEncryptionServiceBuilder_WithClients_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'WithClients'

func (*MockEncryptionServiceBuilder_WithClients_Call) Return

func (*MockEncryptionServiceBuilder_WithClients_Call) Run

func (*MockEncryptionServiceBuilder_WithClients_Call) RunAndReturn

type MockEncryptionService_Decrypt_Call

type MockEncryptionService_Decrypt_Call struct {
	*mock.Call
}

MockEncryptionService_Decrypt_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Decrypt'

func (*MockEncryptionService_Decrypt_Call) Return

func (*MockEncryptionService_Decrypt_Call) Run

func (_c *MockEncryptionService_Decrypt_Call) Run(run func(ciphertext string, associatedData string)) *MockEncryptionService_Decrypt_Call

func (*MockEncryptionService_Decrypt_Call) RunAndReturn

func (_c *MockEncryptionService_Decrypt_Call) RunAndReturn(run func(ciphertext string, associatedData string) (string, error)) *MockEncryptionService_Decrypt_Call

type MockEncryptionService_Disable_Call

type MockEncryptionService_Disable_Call struct {
	*mock.Call
}

MockEncryptionService_Disable_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Disable'

func (*MockEncryptionService_Disable_Call) Return

func (*MockEncryptionService_Disable_Call) Run

func (*MockEncryptionService_Disable_Call) RunAndReturn

type MockEncryptionService_Encrypt_Call

type MockEncryptionService_Encrypt_Call struct {
	*mock.Call
}

MockEncryptionService_Encrypt_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Encrypt'

func (*MockEncryptionService_Encrypt_Call) Return

func (*MockEncryptionService_Encrypt_Call) Run

func (_c *MockEncryptionService_Encrypt_Call) Run(run func(plaintext string, associatedData string)) *MockEncryptionService_Encrypt_Call

func (*MockEncryptionService_Encrypt_Call) RunAndReturn

func (_c *MockEncryptionService_Encrypt_Call) RunAndReturn(run func(plaintext string, associatedData string) (string, error)) *MockEncryptionService_Encrypt_Call

type MockEncryptionService_Expecter

type MockEncryptionService_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockEncryptionService_Expecter) Decrypt

func (_e *MockEncryptionService_Expecter) Decrypt(ciphertext interface{}, associatedData interface{}) *MockEncryptionService_Decrypt_Call

Decrypt is a helper method to define mock.On call

  • ciphertext
  • associatedData

func (*MockEncryptionService_Expecter) Disable

Disable is a helper method to define mock.On call

func (*MockEncryptionService_Expecter) Encrypt

func (_e *MockEncryptionService_Expecter) Encrypt(plaintext interface{}, associatedData interface{}) *MockEncryptionService_Encrypt_Call

Encrypt is a helper method to define mock.On call

  • plaintext
  • associatedData

Jump to