environment

package
v3.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 15, 2025 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockService

type MockService struct {
	mock.Mock
}

MockService is an autogenerated mock type for the Service type

func NewMockService

func NewMockService(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockService

NewMockService creates a new instance of MockService. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockService) EXPECT

func (_m *MockService) EXPECT() *MockService_Expecter

func (*MockService) EnvironList

func (_mock *MockService) EnvironList(repo *model.Repo) ([]*model.Environ, error)

EnvironList provides a mock function for the type MockService

type MockService_EnvironList_Call

type MockService_EnvironList_Call struct {
	*mock.Call
}

MockService_EnvironList_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'EnvironList'

func (*MockService_EnvironList_Call) Return

func (*MockService_EnvironList_Call) Run

func (*MockService_EnvironList_Call) RunAndReturn

func (_c *MockService_EnvironList_Call) RunAndReturn(run func(repo *model.Repo) ([]*model.Environ, error)) *MockService_EnvironList_Call

type MockService_Expecter

type MockService_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockService_Expecter) EnvironList

func (_e *MockService_Expecter) EnvironList(repo interface{}) *MockService_EnvironList_Call

EnvironList is a helper method to define mock.On call

  • repo

Jump to