log

package
v3.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 15, 2025 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockService

type MockService struct {
	mock.Mock
}

MockService is an autogenerated mock type for the Service type

func NewMockService

func NewMockService(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockService

NewMockService creates a new instance of MockService. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockService) EXPECT

func (_m *MockService) EXPECT() *MockService_Expecter

func (*MockService) LogAppend

func (_mock *MockService) LogAppend(step *model.Step, logEntries []*model.LogEntry) error

LogAppend provides a mock function for the type MockService

func (*MockService) LogDelete

func (_mock *MockService) LogDelete(step *model.Step) error

LogDelete provides a mock function for the type MockService

func (*MockService) LogFind

func (_mock *MockService) LogFind(step *model.Step) ([]*model.LogEntry, error)

LogFind provides a mock function for the type MockService

type MockService_Expecter

type MockService_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockService_Expecter) LogAppend

func (_e *MockService_Expecter) LogAppend(step interface{}, logEntries interface{}) *MockService_LogAppend_Call

LogAppend is a helper method to define mock.On call

  • step
  • logEntries

func (*MockService_Expecter) LogDelete

func (_e *MockService_Expecter) LogDelete(step interface{}) *MockService_LogDelete_Call

LogDelete is a helper method to define mock.On call

  • step

func (*MockService_Expecter) LogFind

func (_e *MockService_Expecter) LogFind(step interface{}) *MockService_LogFind_Call

LogFind is a helper method to define mock.On call

  • step

type MockService_LogAppend_Call

type MockService_LogAppend_Call struct {
	*mock.Call
}

MockService_LogAppend_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'LogAppend'

func (*MockService_LogAppend_Call) Return

func (*MockService_LogAppend_Call) Run

func (_c *MockService_LogAppend_Call) Run(run func(step *model.Step, logEntries []*model.LogEntry)) *MockService_LogAppend_Call

func (*MockService_LogAppend_Call) RunAndReturn

func (_c *MockService_LogAppend_Call) RunAndReturn(run func(step *model.Step, logEntries []*model.LogEntry) error) *MockService_LogAppend_Call

type MockService_LogDelete_Call

type MockService_LogDelete_Call struct {
	*mock.Call
}

MockService_LogDelete_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'LogDelete'

func (*MockService_LogDelete_Call) Return

func (*MockService_LogDelete_Call) Run

func (*MockService_LogDelete_Call) RunAndReturn

func (_c *MockService_LogDelete_Call) RunAndReturn(run func(step *model.Step) error) *MockService_LogDelete_Call

type MockService_LogFind_Call

type MockService_LogFind_Call struct {
	*mock.Call
}

MockService_LogFind_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'LogFind'

func (*MockService_LogFind_Call) Return

func (_c *MockService_LogFind_Call) Return(logEntrys []*model.LogEntry, err error) *MockService_LogFind_Call

func (*MockService_LogFind_Call) Run

func (_c *MockService_LogFind_Call) Run(run func(step *model.Step)) *MockService_LogFind_Call

func (*MockService_LogFind_Call) RunAndReturn

func (_c *MockService_LogFind_Call) RunAndReturn(run func(step *model.Step) ([]*model.LogEntry, error)) *MockService_LogFind_Call

Jump to