services

package
v3.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 15, 2025 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockManager

type MockManager struct {
	mock.Mock
}

MockManager is an autogenerated mock type for the Manager type

func NewMockManager

func NewMockManager(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockManager

NewMockManager creates a new instance of MockManager. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockManager) ConfigServiceFromRepo

func (_mock *MockManager) ConfigServiceFromRepo(repo *model.Repo) config.Service

ConfigServiceFromRepo provides a mock function for the type MockManager

func (*MockManager) EXPECT

func (_m *MockManager) EXPECT() *MockManager_Expecter

func (*MockManager) EnvironmentService

func (_mock *MockManager) EnvironmentService() environment.Service

EnvironmentService provides a mock function for the type MockManager

func (*MockManager) ForgeByID

func (_mock *MockManager) ForgeByID(forgeID int64) (forge.Forge, error)

ForgeByID provides a mock function for the type MockManager

func (*MockManager) ForgeFromRepo

func (_mock *MockManager) ForgeFromRepo(repo *model.Repo) (forge.Forge, error)

ForgeFromRepo provides a mock function for the type MockManager

func (*MockManager) ForgeFromUser

func (_mock *MockManager) ForgeFromUser(user *model.User) (forge.Forge, error)

ForgeFromUser provides a mock function for the type MockManager

func (*MockManager) RegistryService

func (_mock *MockManager) RegistryService() registry.Service

RegistryService provides a mock function for the type MockManager

func (*MockManager) RegistryServiceFromRepo

func (_mock *MockManager) RegistryServiceFromRepo(repo *model.Repo) registry.Service

RegistryServiceFromRepo provides a mock function for the type MockManager

func (*MockManager) SecretService

func (_mock *MockManager) SecretService() secret.Service

SecretService provides a mock function for the type MockManager

func (*MockManager) SecretServiceFromRepo

func (_mock *MockManager) SecretServiceFromRepo(repo *model.Repo) secret.Service

SecretServiceFromRepo provides a mock function for the type MockManager

func (*MockManager) SignaturePublicKey

func (_mock *MockManager) SignaturePublicKey() crypto.PublicKey

SignaturePublicKey provides a mock function for the type MockManager

type MockManager_ConfigServiceFromRepo_Call

type MockManager_ConfigServiceFromRepo_Call struct {
	*mock.Call
}

MockManager_ConfigServiceFromRepo_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ConfigServiceFromRepo'

func (*MockManager_ConfigServiceFromRepo_Call) Return

func (*MockManager_ConfigServiceFromRepo_Call) Run

func (*MockManager_ConfigServiceFromRepo_Call) RunAndReturn

type MockManager_EnvironmentService_Call

type MockManager_EnvironmentService_Call struct {
	*mock.Call
}

MockManager_EnvironmentService_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'EnvironmentService'

func (*MockManager_EnvironmentService_Call) Return

func (*MockManager_EnvironmentService_Call) Run

func (*MockManager_EnvironmentService_Call) RunAndReturn

type MockManager_Expecter

type MockManager_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockManager_Expecter) ConfigServiceFromRepo

func (_e *MockManager_Expecter) ConfigServiceFromRepo(repo interface{}) *MockManager_ConfigServiceFromRepo_Call

ConfigServiceFromRepo is a helper method to define mock.On call

  • repo

func (*MockManager_Expecter) EnvironmentService

EnvironmentService is a helper method to define mock.On call

func (*MockManager_Expecter) ForgeByID

func (_e *MockManager_Expecter) ForgeByID(forgeID interface{}) *MockManager_ForgeByID_Call

ForgeByID is a helper method to define mock.On call

  • forgeID

func (*MockManager_Expecter) ForgeFromRepo

func (_e *MockManager_Expecter) ForgeFromRepo(repo interface{}) *MockManager_ForgeFromRepo_Call

ForgeFromRepo is a helper method to define mock.On call

  • repo

func (*MockManager_Expecter) ForgeFromUser

func (_e *MockManager_Expecter) ForgeFromUser(user interface{}) *MockManager_ForgeFromUser_Call

ForgeFromUser is a helper method to define mock.On call

  • user

func (*MockManager_Expecter) RegistryService

RegistryService is a helper method to define mock.On call

func (*MockManager_Expecter) RegistryServiceFromRepo

func (_e *MockManager_Expecter) RegistryServiceFromRepo(repo interface{}) *MockManager_RegistryServiceFromRepo_Call

RegistryServiceFromRepo is a helper method to define mock.On call

  • repo

func (*MockManager_Expecter) SecretService

SecretService is a helper method to define mock.On call

func (*MockManager_Expecter) SecretServiceFromRepo

func (_e *MockManager_Expecter) SecretServiceFromRepo(repo interface{}) *MockManager_SecretServiceFromRepo_Call

SecretServiceFromRepo is a helper method to define mock.On call

  • repo

func (*MockManager_Expecter) SignaturePublicKey

SignaturePublicKey is a helper method to define mock.On call

type MockManager_ForgeByID_Call

type MockManager_ForgeByID_Call struct {
	*mock.Call
}

MockManager_ForgeByID_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ForgeByID'

func (*MockManager_ForgeByID_Call) Return

func (*MockManager_ForgeByID_Call) Run

func (_c *MockManager_ForgeByID_Call) Run(run func(forgeID int64)) *MockManager_ForgeByID_Call

func (*MockManager_ForgeByID_Call) RunAndReturn

func (_c *MockManager_ForgeByID_Call) RunAndReturn(run func(forgeID int64) (forge.Forge, error)) *MockManager_ForgeByID_Call

type MockManager_ForgeFromRepo_Call

type MockManager_ForgeFromRepo_Call struct {
	*mock.Call
}

MockManager_ForgeFromRepo_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ForgeFromRepo'

func (*MockManager_ForgeFromRepo_Call) Return

func (*MockManager_ForgeFromRepo_Call) Run

func (*MockManager_ForgeFromRepo_Call) RunAndReturn

type MockManager_ForgeFromUser_Call

type MockManager_ForgeFromUser_Call struct {
	*mock.Call
}

MockManager_ForgeFromUser_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ForgeFromUser'

func (*MockManager_ForgeFromUser_Call) Return

func (*MockManager_ForgeFromUser_Call) Run

func (*MockManager_ForgeFromUser_Call) RunAndReturn

type MockManager_RegistryServiceFromRepo_Call

type MockManager_RegistryServiceFromRepo_Call struct {
	*mock.Call
}

MockManager_RegistryServiceFromRepo_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'RegistryServiceFromRepo'

func (*MockManager_RegistryServiceFromRepo_Call) Return

func (*MockManager_RegistryServiceFromRepo_Call) Run

func (*MockManager_RegistryServiceFromRepo_Call) RunAndReturn

type MockManager_RegistryService_Call

type MockManager_RegistryService_Call struct {
	*mock.Call
}

MockManager_RegistryService_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'RegistryService'

func (*MockManager_RegistryService_Call) Return

func (*MockManager_RegistryService_Call) Run

func (*MockManager_RegistryService_Call) RunAndReturn

type MockManager_SecretServiceFromRepo_Call

type MockManager_SecretServiceFromRepo_Call struct {
	*mock.Call
}

MockManager_SecretServiceFromRepo_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'SecretServiceFromRepo'

func (*MockManager_SecretServiceFromRepo_Call) Return

func (*MockManager_SecretServiceFromRepo_Call) Run

func (*MockManager_SecretServiceFromRepo_Call) RunAndReturn

type MockManager_SecretService_Call

type MockManager_SecretService_Call struct {
	*mock.Call
}

MockManager_SecretService_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'SecretService'

func (*MockManager_SecretService_Call) Return

func (*MockManager_SecretService_Call) Run

func (*MockManager_SecretService_Call) RunAndReturn

type MockManager_SignaturePublicKey_Call

type MockManager_SignaturePublicKey_Call struct {
	*mock.Call
}

MockManager_SignaturePublicKey_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'SignaturePublicKey'

func (*MockManager_SignaturePublicKey_Call) Return

func (*MockManager_SignaturePublicKey_Call) Run

func (*MockManager_SignaturePublicKey_Call) RunAndReturn

type MockSetupForge

type MockSetupForge struct {
	mock.Mock
}

MockSetupForge is an autogenerated mock type for the SetupForge type

func NewMockSetupForge

func NewMockSetupForge(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockSetupForge

NewMockSetupForge creates a new instance of MockSetupForge. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockSetupForge) EXPECT

func (*MockSetupForge) Execute

func (_m *MockSetupForge) Execute(_a0 *model.Forge) (forge.Forge, error)

Execute provides a mock function with given fields: _a0

type MockSetupForge_Execute_Call

type MockSetupForge_Execute_Call struct {
	*mock.Call
}

MockSetupForge_Execute_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Execute'

func (*MockSetupForge_Execute_Call) Return

func (*MockSetupForge_Execute_Call) Run

func (*MockSetupForge_Execute_Call) RunAndReturn

type MockSetupForge_Expecter

type MockSetupForge_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockSetupForge_Expecter) Execute

func (_e *MockSetupForge_Expecter) Execute(_a0 interface{}) *MockSetupForge_Execute_Call

Execute is a helper method to define mock.On call

  • _a0 *model.Forge

Jump to