Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockFieldFn ¶
MockFieldFn is an autogenerated mock type for the FieldFn type
func NewMockFieldFn ¶
func NewMockFieldFn(t interface {
mock.TestingT
Cleanup(func())
}) *MockFieldFn
NewMockFieldFn creates a new instance of MockFieldFn. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MockFieldFn) EXPECT ¶
func (_m *MockFieldFn) EXPECT() *MockFieldFn_Expecter
func (*MockFieldFn) Execute ¶
func (_m *MockFieldFn) Execute(obj any) string
Execute provides a mock function with given fields: obj
type MockFieldFn_Execute_Call ¶
MockFieldFn_Execute_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Execute'
func (*MockFieldFn_Execute_Call) Return ¶
func (_c *MockFieldFn_Execute_Call) Return(_a0 string) *MockFieldFn_Execute_Call
func (*MockFieldFn_Execute_Call) Run ¶
func (_c *MockFieldFn_Execute_Call) Run(run func(obj any)) *MockFieldFn_Execute_Call
func (*MockFieldFn_Execute_Call) RunAndReturn ¶
func (_c *MockFieldFn_Execute_Call) RunAndReturn(run func(any) string) *MockFieldFn_Execute_Call
type MockFieldFn_Expecter ¶
type MockFieldFn_Expecter struct {
// contains filtered or unexported fields
}
func (*MockFieldFn_Expecter) Execute ¶
func (_e *MockFieldFn_Expecter) Execute(obj interface{}) *MockFieldFn_Execute_Call
Execute is a helper method to define mock.On call
- obj any
Click to show internal directories.
Click to hide internal directories.