Documentation
¶
Index ¶
- type MockEncryptionBuilder
- type MockEncryptionBuilder_Build_Call
- type MockEncryptionBuilder_Expecter
- type MockEncryptionBuilder_WithClient_Call
- func (_c *MockEncryptionBuilder_WithClient_Call) Return(encryptionBuilder types.EncryptionBuilder) *MockEncryptionBuilder_WithClient_Call
- func (_c *MockEncryptionBuilder_WithClient_Call) Run(run func(client types.EncryptionClient)) *MockEncryptionBuilder_WithClient_Call
- func (_c *MockEncryptionBuilder_WithClient_Call) RunAndReturn(run func(client types.EncryptionClient) types.EncryptionBuilder) *MockEncryptionBuilder_WithClient_Call
- type MockEncryptionClient
- func (_m *MockEncryptionClient) EXPECT() *MockEncryptionClient_Expecter
- func (_mock *MockEncryptionClient) EnableEncryption() error
- func (_mock *MockEncryptionClient) MigrateEncryption(newEncryption types.EncryptionService) error
- func (_mock *MockEncryptionClient) SetEncryptionService(encryption types.EncryptionService) error
- type MockEncryptionClient_EnableEncryption_Call
- func (_c *MockEncryptionClient_EnableEncryption_Call) Return(err error) *MockEncryptionClient_EnableEncryption_Call
- func (_c *MockEncryptionClient_EnableEncryption_Call) Run(run func()) *MockEncryptionClient_EnableEncryption_Call
- func (_c *MockEncryptionClient_EnableEncryption_Call) RunAndReturn(run func() error) *MockEncryptionClient_EnableEncryption_Call
- type MockEncryptionClient_Expecter
- func (_e *MockEncryptionClient_Expecter) EnableEncryption() *MockEncryptionClient_EnableEncryption_Call
- func (_e *MockEncryptionClient_Expecter) MigrateEncryption(newEncryption interface{}) *MockEncryptionClient_MigrateEncryption_Call
- func (_e *MockEncryptionClient_Expecter) SetEncryptionService(encryption interface{}) *MockEncryptionClient_SetEncryptionService_Call
- type MockEncryptionClient_MigrateEncryption_Call
- func (_c *MockEncryptionClient_MigrateEncryption_Call) Return(err error) *MockEncryptionClient_MigrateEncryption_Call
- func (_c *MockEncryptionClient_MigrateEncryption_Call) Run(run func(newEncryption types.EncryptionService)) *MockEncryptionClient_MigrateEncryption_Call
- func (_c *MockEncryptionClient_MigrateEncryption_Call) RunAndReturn(run func(newEncryption types.EncryptionService) error) *MockEncryptionClient_MigrateEncryption_Call
- type MockEncryptionClient_SetEncryptionService_Call
- func (_c *MockEncryptionClient_SetEncryptionService_Call) Return(err error) *MockEncryptionClient_SetEncryptionService_Call
- func (_c *MockEncryptionClient_SetEncryptionService_Call) Run(run func(encryption types.EncryptionService)) *MockEncryptionClient_SetEncryptionService_Call
- func (_c *MockEncryptionClient_SetEncryptionService_Call) RunAndReturn(run func(encryption types.EncryptionService) error) *MockEncryptionClient_SetEncryptionService_Call
- type MockEncryptionService
- func (_mock *MockEncryptionService) Decrypt(ciphertext string, associatedData string) (string, error)
- func (_mock *MockEncryptionService) Disable() error
- func (_m *MockEncryptionService) EXPECT() *MockEncryptionService_Expecter
- func (_mock *MockEncryptionService) Encrypt(plaintext string, associatedData string) (string, error)
- type MockEncryptionServiceBuilder
- type MockEncryptionServiceBuilder_Build_Call
- func (_c *MockEncryptionServiceBuilder_Build_Call) Return(encryptionService types.EncryptionService, err error) *MockEncryptionServiceBuilder_Build_Call
- func (_c *MockEncryptionServiceBuilder_Build_Call) Run(run func()) *MockEncryptionServiceBuilder_Build_Call
- func (_c *MockEncryptionServiceBuilder_Build_Call) RunAndReturn(run func() (types.EncryptionService, error)) *MockEncryptionServiceBuilder_Build_Call
- type MockEncryptionServiceBuilder_Expecter
- type MockEncryptionServiceBuilder_WithClients_Call
- func (_c *MockEncryptionServiceBuilder_WithClients_Call) Return(encryptionServiceBuilder types.EncryptionServiceBuilder) *MockEncryptionServiceBuilder_WithClients_Call
- func (_c *MockEncryptionServiceBuilder_WithClients_Call) Run(run func(clients []types.EncryptionClient)) *MockEncryptionServiceBuilder_WithClients_Call
- func (_c *MockEncryptionServiceBuilder_WithClients_Call) RunAndReturn(run func(clients []types.EncryptionClient) types.EncryptionServiceBuilder) *MockEncryptionServiceBuilder_WithClients_Call
- type MockEncryptionService_Decrypt_Call
- func (_c *MockEncryptionService_Decrypt_Call) Return(s string, err error) *MockEncryptionService_Decrypt_Call
- func (_c *MockEncryptionService_Decrypt_Call) Run(run func(ciphertext string, associatedData string)) *MockEncryptionService_Decrypt_Call
- func (_c *MockEncryptionService_Decrypt_Call) RunAndReturn(run func(ciphertext string, associatedData string) (string, error)) *MockEncryptionService_Decrypt_Call
- type MockEncryptionService_Disable_Call
- func (_c *MockEncryptionService_Disable_Call) Return(err error) *MockEncryptionService_Disable_Call
- func (_c *MockEncryptionService_Disable_Call) Run(run func()) *MockEncryptionService_Disable_Call
- func (_c *MockEncryptionService_Disable_Call) RunAndReturn(run func() error) *MockEncryptionService_Disable_Call
- type MockEncryptionService_Encrypt_Call
- func (_c *MockEncryptionService_Encrypt_Call) Return(s string, err error) *MockEncryptionService_Encrypt_Call
- func (_c *MockEncryptionService_Encrypt_Call) Run(run func(plaintext string, associatedData string)) *MockEncryptionService_Encrypt_Call
- func (_c *MockEncryptionService_Encrypt_Call) RunAndReturn(run func(plaintext string, associatedData string) (string, error)) *MockEncryptionService_Encrypt_Call
- type MockEncryptionService_Expecter
- func (_e *MockEncryptionService_Expecter) Decrypt(ciphertext interface{}, associatedData interface{}) *MockEncryptionService_Decrypt_Call
- func (_e *MockEncryptionService_Expecter) Disable() *MockEncryptionService_Disable_Call
- func (_e *MockEncryptionService_Expecter) Encrypt(plaintext interface{}, associatedData interface{}) *MockEncryptionService_Encrypt_Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockEncryptionBuilder ¶
MockEncryptionBuilder is an autogenerated mock type for the EncryptionBuilder type
func NewMockEncryptionBuilder ¶
func NewMockEncryptionBuilder(t interface {
mock.TestingT
Cleanup(func())
}) *MockEncryptionBuilder
NewMockEncryptionBuilder creates a new instance of MockEncryptionBuilder. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MockEncryptionBuilder) Build ¶
func (_mock *MockEncryptionBuilder) Build() error
Build provides a mock function for the type MockEncryptionBuilder
func (*MockEncryptionBuilder) EXPECT ¶
func (_m *MockEncryptionBuilder) EXPECT() *MockEncryptionBuilder_Expecter
func (*MockEncryptionBuilder) WithClient ¶
func (_mock *MockEncryptionBuilder) WithClient(client types.EncryptionClient) types.EncryptionBuilder
WithClient provides a mock function for the type MockEncryptionBuilder
type MockEncryptionBuilder_Build_Call ¶
MockEncryptionBuilder_Build_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Build'
func (*MockEncryptionBuilder_Build_Call) Return ¶
func (_c *MockEncryptionBuilder_Build_Call) Return(err error) *MockEncryptionBuilder_Build_Call
func (*MockEncryptionBuilder_Build_Call) Run ¶
func (_c *MockEncryptionBuilder_Build_Call) Run(run func()) *MockEncryptionBuilder_Build_Call
func (*MockEncryptionBuilder_Build_Call) RunAndReturn ¶
func (_c *MockEncryptionBuilder_Build_Call) RunAndReturn(run func() error) *MockEncryptionBuilder_Build_Call
type MockEncryptionBuilder_Expecter ¶
type MockEncryptionBuilder_Expecter struct {
// contains filtered or unexported fields
}
func (*MockEncryptionBuilder_Expecter) Build ¶
func (_e *MockEncryptionBuilder_Expecter) Build() *MockEncryptionBuilder_Build_Call
Build is a helper method to define mock.On call
func (*MockEncryptionBuilder_Expecter) WithClient ¶
func (_e *MockEncryptionBuilder_Expecter) WithClient(client interface{}) *MockEncryptionBuilder_WithClient_Call
WithClient is a helper method to define mock.On call
- client
type MockEncryptionBuilder_WithClient_Call ¶
MockEncryptionBuilder_WithClient_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'WithClient'
func (*MockEncryptionBuilder_WithClient_Call) Return ¶
func (_c *MockEncryptionBuilder_WithClient_Call) Return(encryptionBuilder types.EncryptionBuilder) *MockEncryptionBuilder_WithClient_Call
func (*MockEncryptionBuilder_WithClient_Call) Run ¶
func (_c *MockEncryptionBuilder_WithClient_Call) Run(run func(client types.EncryptionClient)) *MockEncryptionBuilder_WithClient_Call
func (*MockEncryptionBuilder_WithClient_Call) RunAndReturn ¶
func (_c *MockEncryptionBuilder_WithClient_Call) RunAndReturn(run func(client types.EncryptionClient) types.EncryptionBuilder) *MockEncryptionBuilder_WithClient_Call
type MockEncryptionClient ¶
MockEncryptionClient is an autogenerated mock type for the EncryptionClient type
func NewMockEncryptionClient ¶
func NewMockEncryptionClient(t interface {
mock.TestingT
Cleanup(func())
}) *MockEncryptionClient
NewMockEncryptionClient creates a new instance of MockEncryptionClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MockEncryptionClient) EXPECT ¶
func (_m *MockEncryptionClient) EXPECT() *MockEncryptionClient_Expecter
func (*MockEncryptionClient) EnableEncryption ¶
func (_mock *MockEncryptionClient) EnableEncryption() error
EnableEncryption provides a mock function for the type MockEncryptionClient
func (*MockEncryptionClient) MigrateEncryption ¶
func (_mock *MockEncryptionClient) MigrateEncryption(newEncryption types.EncryptionService) error
MigrateEncryption provides a mock function for the type MockEncryptionClient
func (*MockEncryptionClient) SetEncryptionService ¶
func (_mock *MockEncryptionClient) SetEncryptionService(encryption types.EncryptionService) error
SetEncryptionService provides a mock function for the type MockEncryptionClient
type MockEncryptionClient_EnableEncryption_Call ¶
MockEncryptionClient_EnableEncryption_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'EnableEncryption'
func (*MockEncryptionClient_EnableEncryption_Call) Return ¶
func (_c *MockEncryptionClient_EnableEncryption_Call) Return(err error) *MockEncryptionClient_EnableEncryption_Call
func (*MockEncryptionClient_EnableEncryption_Call) Run ¶
func (_c *MockEncryptionClient_EnableEncryption_Call) Run(run func()) *MockEncryptionClient_EnableEncryption_Call
func (*MockEncryptionClient_EnableEncryption_Call) RunAndReturn ¶
func (_c *MockEncryptionClient_EnableEncryption_Call) RunAndReturn(run func() error) *MockEncryptionClient_EnableEncryption_Call
type MockEncryptionClient_Expecter ¶
type MockEncryptionClient_Expecter struct {
// contains filtered or unexported fields
}
func (*MockEncryptionClient_Expecter) EnableEncryption ¶
func (_e *MockEncryptionClient_Expecter) EnableEncryption() *MockEncryptionClient_EnableEncryption_Call
EnableEncryption is a helper method to define mock.On call
func (*MockEncryptionClient_Expecter) MigrateEncryption ¶
func (_e *MockEncryptionClient_Expecter) MigrateEncryption(newEncryption interface{}) *MockEncryptionClient_MigrateEncryption_Call
MigrateEncryption is a helper method to define mock.On call
- newEncryption
func (*MockEncryptionClient_Expecter) SetEncryptionService ¶
func (_e *MockEncryptionClient_Expecter) SetEncryptionService(encryption interface{}) *MockEncryptionClient_SetEncryptionService_Call
SetEncryptionService is a helper method to define mock.On call
- encryption
type MockEncryptionClient_MigrateEncryption_Call ¶
MockEncryptionClient_MigrateEncryption_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'MigrateEncryption'
func (*MockEncryptionClient_MigrateEncryption_Call) Return ¶
func (_c *MockEncryptionClient_MigrateEncryption_Call) Return(err error) *MockEncryptionClient_MigrateEncryption_Call
func (*MockEncryptionClient_MigrateEncryption_Call) Run ¶
func (_c *MockEncryptionClient_MigrateEncryption_Call) Run(run func(newEncryption types.EncryptionService)) *MockEncryptionClient_MigrateEncryption_Call
func (*MockEncryptionClient_MigrateEncryption_Call) RunAndReturn ¶
func (_c *MockEncryptionClient_MigrateEncryption_Call) RunAndReturn(run func(newEncryption types.EncryptionService) error) *MockEncryptionClient_MigrateEncryption_Call
type MockEncryptionClient_SetEncryptionService_Call ¶
MockEncryptionClient_SetEncryptionService_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'SetEncryptionService'
func (*MockEncryptionClient_SetEncryptionService_Call) Return ¶
func (_c *MockEncryptionClient_SetEncryptionService_Call) Return(err error) *MockEncryptionClient_SetEncryptionService_Call
func (*MockEncryptionClient_SetEncryptionService_Call) Run ¶
func (_c *MockEncryptionClient_SetEncryptionService_Call) Run(run func(encryption types.EncryptionService)) *MockEncryptionClient_SetEncryptionService_Call
func (*MockEncryptionClient_SetEncryptionService_Call) RunAndReturn ¶
func (_c *MockEncryptionClient_SetEncryptionService_Call) RunAndReturn(run func(encryption types.EncryptionService) error) *MockEncryptionClient_SetEncryptionService_Call
type MockEncryptionService ¶
MockEncryptionService is an autogenerated mock type for the EncryptionService type
func NewMockEncryptionService ¶
func NewMockEncryptionService(t interface {
mock.TestingT
Cleanup(func())
}) *MockEncryptionService
NewMockEncryptionService creates a new instance of MockEncryptionService. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MockEncryptionService) Decrypt ¶
func (_mock *MockEncryptionService) Decrypt(ciphertext string, associatedData string) (string, error)
Decrypt provides a mock function for the type MockEncryptionService
func (*MockEncryptionService) Disable ¶
func (_mock *MockEncryptionService) Disable() error
Disable provides a mock function for the type MockEncryptionService
func (*MockEncryptionService) EXPECT ¶
func (_m *MockEncryptionService) EXPECT() *MockEncryptionService_Expecter
type MockEncryptionServiceBuilder ¶
MockEncryptionServiceBuilder is an autogenerated mock type for the EncryptionServiceBuilder type
func NewMockEncryptionServiceBuilder ¶
func NewMockEncryptionServiceBuilder(t interface {
mock.TestingT
Cleanup(func())
}) *MockEncryptionServiceBuilder
NewMockEncryptionServiceBuilder creates a new instance of MockEncryptionServiceBuilder. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MockEncryptionServiceBuilder) Build ¶
func (_mock *MockEncryptionServiceBuilder) Build() (types.EncryptionService, error)
Build provides a mock function for the type MockEncryptionServiceBuilder
func (*MockEncryptionServiceBuilder) EXPECT ¶
func (_m *MockEncryptionServiceBuilder) EXPECT() *MockEncryptionServiceBuilder_Expecter
func (*MockEncryptionServiceBuilder) WithClients ¶
func (_mock *MockEncryptionServiceBuilder) WithClients(clients []types.EncryptionClient) types.EncryptionServiceBuilder
WithClients provides a mock function for the type MockEncryptionServiceBuilder
type MockEncryptionServiceBuilder_Build_Call ¶
MockEncryptionServiceBuilder_Build_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Build'
func (*MockEncryptionServiceBuilder_Build_Call) Return ¶
func (_c *MockEncryptionServiceBuilder_Build_Call) Return(encryptionService types.EncryptionService, err error) *MockEncryptionServiceBuilder_Build_Call
func (*MockEncryptionServiceBuilder_Build_Call) Run ¶
func (_c *MockEncryptionServiceBuilder_Build_Call) Run(run func()) *MockEncryptionServiceBuilder_Build_Call
func (*MockEncryptionServiceBuilder_Build_Call) RunAndReturn ¶
func (_c *MockEncryptionServiceBuilder_Build_Call) RunAndReturn(run func() (types.EncryptionService, error)) *MockEncryptionServiceBuilder_Build_Call
type MockEncryptionServiceBuilder_Expecter ¶
type MockEncryptionServiceBuilder_Expecter struct {
// contains filtered or unexported fields
}
func (*MockEncryptionServiceBuilder_Expecter) Build ¶
func (_e *MockEncryptionServiceBuilder_Expecter) Build() *MockEncryptionServiceBuilder_Build_Call
Build is a helper method to define mock.On call
func (*MockEncryptionServiceBuilder_Expecter) WithClients ¶
func (_e *MockEncryptionServiceBuilder_Expecter) WithClients(clients interface{}) *MockEncryptionServiceBuilder_WithClients_Call
WithClients is a helper method to define mock.On call
- clients
type MockEncryptionServiceBuilder_WithClients_Call ¶
MockEncryptionServiceBuilder_WithClients_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'WithClients'
func (*MockEncryptionServiceBuilder_WithClients_Call) Return ¶
func (_c *MockEncryptionServiceBuilder_WithClients_Call) Return(encryptionServiceBuilder types.EncryptionServiceBuilder) *MockEncryptionServiceBuilder_WithClients_Call
func (*MockEncryptionServiceBuilder_WithClients_Call) Run ¶
func (_c *MockEncryptionServiceBuilder_WithClients_Call) Run(run func(clients []types.EncryptionClient)) *MockEncryptionServiceBuilder_WithClients_Call
func (*MockEncryptionServiceBuilder_WithClients_Call) RunAndReturn ¶
func (_c *MockEncryptionServiceBuilder_WithClients_Call) RunAndReturn(run func(clients []types.EncryptionClient) types.EncryptionServiceBuilder) *MockEncryptionServiceBuilder_WithClients_Call
type MockEncryptionService_Decrypt_Call ¶
MockEncryptionService_Decrypt_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Decrypt'
func (*MockEncryptionService_Decrypt_Call) Return ¶
func (_c *MockEncryptionService_Decrypt_Call) Return(s string, err error) *MockEncryptionService_Decrypt_Call
func (*MockEncryptionService_Decrypt_Call) Run ¶
func (_c *MockEncryptionService_Decrypt_Call) Run(run func(ciphertext string, associatedData string)) *MockEncryptionService_Decrypt_Call
func (*MockEncryptionService_Decrypt_Call) RunAndReturn ¶
func (_c *MockEncryptionService_Decrypt_Call) RunAndReturn(run func(ciphertext string, associatedData string) (string, error)) *MockEncryptionService_Decrypt_Call
type MockEncryptionService_Disable_Call ¶
MockEncryptionService_Disable_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Disable'
func (*MockEncryptionService_Disable_Call) Return ¶
func (_c *MockEncryptionService_Disable_Call) Return(err error) *MockEncryptionService_Disable_Call
func (*MockEncryptionService_Disable_Call) Run ¶
func (_c *MockEncryptionService_Disable_Call) Run(run func()) *MockEncryptionService_Disable_Call
func (*MockEncryptionService_Disable_Call) RunAndReturn ¶
func (_c *MockEncryptionService_Disable_Call) RunAndReturn(run func() error) *MockEncryptionService_Disable_Call
type MockEncryptionService_Encrypt_Call ¶
MockEncryptionService_Encrypt_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Encrypt'
func (*MockEncryptionService_Encrypt_Call) Return ¶
func (_c *MockEncryptionService_Encrypt_Call) Return(s string, err error) *MockEncryptionService_Encrypt_Call
func (*MockEncryptionService_Encrypt_Call) Run ¶
func (_c *MockEncryptionService_Encrypt_Call) Run(run func(plaintext string, associatedData string)) *MockEncryptionService_Encrypt_Call
func (*MockEncryptionService_Encrypt_Call) RunAndReturn ¶
func (_c *MockEncryptionService_Encrypt_Call) RunAndReturn(run func(plaintext string, associatedData string) (string, error)) *MockEncryptionService_Encrypt_Call
type MockEncryptionService_Expecter ¶
type MockEncryptionService_Expecter struct {
// contains filtered or unexported fields
}
func (*MockEncryptionService_Expecter) Decrypt ¶
func (_e *MockEncryptionService_Expecter) Decrypt(ciphertext interface{}, associatedData interface{}) *MockEncryptionService_Decrypt_Call
Decrypt is a helper method to define mock.On call
- ciphertext
- associatedData
func (*MockEncryptionService_Expecter) Disable ¶
func (_e *MockEncryptionService_Expecter) Disable() *MockEncryptionService_Disable_Call
Disable is a helper method to define mock.On call
func (*MockEncryptionService_Expecter) Encrypt ¶
func (_e *MockEncryptionService_Expecter) Encrypt(plaintext interface{}, associatedData interface{}) *MockEncryptionService_Encrypt_Call
Encrypt is a helper method to define mock.On call
- plaintext
- associatedData