Documentation
¶
Index ¶
- type MockPublisher
- type MockPublisher_Expecter
- type MockPublisher_Publish_Call
- type MockPublisher_Subscribe_Call
- func (_c *MockPublisher_Subscribe_Call) Return() *MockPublisher_Subscribe_Call
- func (_c *MockPublisher_Subscribe_Call) Run(run func(c context.Context, receiver pubsub.Receiver)) *MockPublisher_Subscribe_Call
- func (_c *MockPublisher_Subscribe_Call) RunAndReturn(run func(c context.Context, receiver pubsub.Receiver)) *MockPublisher_Subscribe_Call
- type MockReceiver
- type MockReceiver_Execute_Call
- type MockReceiver_Expecter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockPublisher ¶
MockPublisher is an autogenerated mock type for the Publisher type
func NewMockPublisher ¶
func NewMockPublisher(t interface {
mock.TestingT
Cleanup(func())
}) *MockPublisher
NewMockPublisher creates a new instance of MockPublisher. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MockPublisher) EXPECT ¶
func (_m *MockPublisher) EXPECT() *MockPublisher_Expecter
func (*MockPublisher) Publish ¶
func (_mock *MockPublisher) Publish(message pubsub.Message)
Publish provides a mock function for the type MockPublisher
type MockPublisher_Expecter ¶
type MockPublisher_Expecter struct {
// contains filtered or unexported fields
}
func (*MockPublisher_Expecter) Publish ¶
func (_e *MockPublisher_Expecter) Publish(message interface{}) *MockPublisher_Publish_Call
Publish is a helper method to define mock.On call
- message pubsub.Message
func (*MockPublisher_Expecter) Subscribe ¶
func (_e *MockPublisher_Expecter) Subscribe(c interface{}, receiver interface{}) *MockPublisher_Subscribe_Call
Subscribe is a helper method to define mock.On call
- c context.Context
- receiver pubsub.Receiver
type MockPublisher_Publish_Call ¶
MockPublisher_Publish_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Publish'
func (*MockPublisher_Publish_Call) Return ¶
func (_c *MockPublisher_Publish_Call) Return() *MockPublisher_Publish_Call
func (*MockPublisher_Publish_Call) Run ¶
func (_c *MockPublisher_Publish_Call) Run(run func(message pubsub.Message)) *MockPublisher_Publish_Call
func (*MockPublisher_Publish_Call) RunAndReturn ¶
func (_c *MockPublisher_Publish_Call) RunAndReturn(run func(message pubsub.Message)) *MockPublisher_Publish_Call
type MockPublisher_Subscribe_Call ¶
MockPublisher_Subscribe_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Subscribe'
func (*MockPublisher_Subscribe_Call) Return ¶
func (_c *MockPublisher_Subscribe_Call) Return() *MockPublisher_Subscribe_Call
func (*MockPublisher_Subscribe_Call) Run ¶
func (_c *MockPublisher_Subscribe_Call) Run(run func(c context.Context, receiver pubsub.Receiver)) *MockPublisher_Subscribe_Call
func (*MockPublisher_Subscribe_Call) RunAndReturn ¶
func (_c *MockPublisher_Subscribe_Call) RunAndReturn(run func(c context.Context, receiver pubsub.Receiver)) *MockPublisher_Subscribe_Call
type MockReceiver ¶
MockReceiver is an autogenerated mock type for the Receiver type
func NewMockReceiver ¶
func NewMockReceiver(t interface {
mock.TestingT
Cleanup(func())
}) *MockReceiver
NewMockReceiver creates a new instance of MockReceiver. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MockReceiver) EXPECT ¶
func (_m *MockReceiver) EXPECT() *MockReceiver_Expecter
func (*MockReceiver) Execute ¶
func (_m *MockReceiver) Execute(_a0 pubsub.Message)
Execute provides a mock function with given fields: _a0
type MockReceiver_Execute_Call ¶
MockReceiver_Execute_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Execute'
func (*MockReceiver_Execute_Call) Return ¶
func (_c *MockReceiver_Execute_Call) Return() *MockReceiver_Execute_Call
func (*MockReceiver_Execute_Call) Run ¶
func (_c *MockReceiver_Execute_Call) Run(run func(_a0 pubsub.Message)) *MockReceiver_Execute_Call
func (*MockReceiver_Execute_Call) RunAndReturn ¶
func (_c *MockReceiver_Execute_Call) RunAndReturn(run func(pubsub.Message)) *MockReceiver_Execute_Call
type MockReceiver_Expecter ¶
type MockReceiver_Expecter struct {
// contains filtered or unexported fields
}
func (*MockReceiver_Expecter) Execute ¶
func (_e *MockReceiver_Expecter) Execute(_a0 interface{}) *MockReceiver_Execute_Call
Execute is a helper method to define mock.On call
- _a0 pubsub.Message